@@ -1,8 +1,8 @@
 /*
-  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
     https://imagemagick.org/script/license.php
@@ -38,7 +38,7 @@ typedef enum
   ListLengthResource
 } ResourceType;
 
-#define MagickResourceInfinity  MagickULLConstant(~0)
+#define MagickResourceInfinity  (MagickULLConstant(~0) >> 1)
 
 extern MagickExport int
   AcquireUniqueFileResource(char *);
